Module blaxel.core.client.models.function_kit
=============================================

Classes
-------

`FunctionKit(description: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, schema: blaxel.core.client.types.Unset | ForwardRef('FunctionSchema') = <blaxel.core.client.types.Unset object>)`
:   Function kit
    
    Attributes:
        description (Union[Unset, str]): Description of the function kit, very important for the agent to work with your
            kit
        name (Union[Unset, str]): The kit name, very important for the agent to work with your kit
        schema (Union[Unset, FunctionSchema]): Function schema
    
    Method generated by attrs for class FunctionKit.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `description`
    :

    `name`
    :

    `schema`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :